<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kcorrmeter" version="1">
<MenuBar>
	<Menu name="file"><text>&amp;File</text>
	    <Action name="resume" />
	    <Action name="halt" />
	    <Separator />
	</Menu>
  <Menu name="configure"><text>&amp;Configure</text>
    <Action name="corr_settings"/>
  </Menu>
</MenuBar>

<Menu name="rb_popup">
  <Action name="corr_settings"/>
  <Separator />
  <Action name="resume" />
  <Action name="halt" />
</Menu>

</kpartgui>
